@@ -3,8 +3,8 @@
 ;;; Code:
 
 
-;;;### (autoloads nil "preview" "preview.el" (23076 26625 394784
-;;;;;;  800000))
+;;;### (autoloads nil "preview" "preview.el" (25122 39049 217449
+;;;;;;  100000))
 ;;; Generated autoloads from preview.el
 
 (autoload 'preview-install-styles "preview" "\
@@ -23,16 +23,12 @@ files are no longer needed in the search path.
 (autoload 'LaTeX-preview-setup "preview" "\
 Hook function for embedding the preview package into AUCTeX.
 This is called by `LaTeX-mode-hook' and changes AUCTeX variables
-to add the preview functionality.
-
-\(fn)" nil nil)
+to add the preview functionality." nil nil)
 
 (autoload 'preview-report-bug "preview" "\
-Report a bug in the preview-latex package.
+Report a bug in the preview-latex package." t nil)
 
-\(fn)" t nil)
-
-(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "preview" '("preview-" "TeX-" "desktop-buffer-preview")))
+(if (fboundp 'register-definition-prefixes) (register-definition-prefixes "preview" '("TeX-" "desktop-buffer-preview" "preview-")))
 
 ;;;***
 
